@@ -7,6 +7,8 @@ logger = logging.getLogger(__name__)
 logging.basicConfig(level=logging.WARNING)
 
 def closeOpen(string):
+	# TODO: Fix overwriting on strings
+	# `Output(3,1,"Masses, heavy to light, in kilograms.Assumes no friction and vi 0"` becomes `output(1, 3, "n kilograms.Assumes no friction and vi 0"")`
 	newString = ""
 	# Function for closing open quotation marks/parenthesis
 	open = False
@@ -53,8 +55,31 @@ def fixEquals(string):
 	# Change = to == if not between quotes
 	return re.sub(r'(?!\B"[^"]*)(?<![<>!])\=(?!\()+(?![^"]*"\B)', " == ", string)
 
+def parenthesis_split(sentence,separator=" ",lparen="(",rparen=")"):
+	nb_brackets=0
+	sentence = sentence.strip(separator) # get rid of leading/trailing seps
 
-class BasicParser(object):
+	l = [0]
+	for i, c in enumerate(sentence):
+		if c == lparen:
+			nb_brackets += 1
+		elif c == rparen:
+			nb_brackets -= 1
+		elif c == separator and nb_brackets == 0:
+			l.append(i)
+		# handle malformed string
+		if nb_brackets < 0:
+			raise Exception("Syntax error")
+
+	l.append(len(sentence))
+	# handle missing closing parentheses
+	if nb_brackets>0:
+		raise Exception("Syntax error")
+
+	return([sentence[i:j].strip(separator) for i,j in zip(l,l[1:])])
+
+
+class TIBasicParser(object):
 	def __init__(self, basic):
 		if isinstance(basic, list):
 			self.basic = basic
@@ -64,7 +89,7 @@ class BasicParser(object):
 			raise TypeError("basic must be list or str, not {}".format(str(type(basic))))
 
 		# Utility Functions
-		self.UTILS = {"wait": {"code": [""], "imports": ["import time"], "enabled": False}, "menu": {"code": [""], "imports": ["import dialog"], "enabled": False}, "math": {"code": [""], "imports": ["import math"], "enabled": False}}
+		self.UTILS = {"wait": {"code": [""], "imports": ["import time"], "enabled": False}, "menu": {"code": [""], "imports": ["import dialog"], "enabled": False}, "math": {"code": [""], "imports": ["import math"], "enabled": False}, 'random': {'code': [''], 'imports': ['import random'], 'enabled': False}}
 		here = os.path.abspath(os.path.dirname(__file__))
 		for file in [file for file in os.listdir(os.path.join(here, "utils")) if os.path.isfile(os.path.join(here, "utils", file))]:
 			with open(os.path.join(here, "utils", file)) as f:
@@ -106,14 +131,14 @@ class BasicParser(object):
 					self.indentIncrease = True
 				elif re.search(r"If.*[^\"]:", line) != None:
 					# If statement on 1 line
-					statement = ["if " + line.lstrip("If ").split(":", 1)[0] + ":", "\t" + self.convertLine(index + 1, line.lstrip("If ").split(":", 1)[1])]
+					statement = ["if " + fixEquals(line.lstrip("If ").split(":", 1)[0]) + ":", "\t" + self.convertLine(index + 1, line.lstrip("If ").split(":", 1)[1])]
 				else:
 					# If statement on 2 lines; no Then
-					statement = ["if " + line.lstrip("If ") + ":", '\t' + self.convertLine(index + 1, self.basic[index + 1])]
+					statement = ["if " + fixEquals(line.lstrip("If ")) + ":", '\t' + self.convertLine(index + 1, self.basic[index + 1])]
 			except IndexError:
 				# Last line in file, test for 1 line If statement
 				if re.search(r"If.*[^\"]:", line) != None:
-					statement = ["if " + line.lstrip("If ").split(":", 1)[0] + ":", "\t" + self.convertLine(index + 1, line.lstrip("If ").split(":", 1)[1])]
+					statement = ["if " + fixEquals(line.lstrip("If ").split(":", 1)[0]) + ":", "\t" + self.convertLine(index + 1, line.lstrip("If ").split(":", 1)[1])]
 		elif line == "Then":
 			return None
 		# Elif
@@ -186,6 +211,7 @@ class BasicParser(object):
 		elif line.startswith("DelVar"):
 			statement = "del " + line[7:]
 		# Prompt
+		# TODO: Fix prompt after Output going over output
 		elif line.startswith("Prompt"):
 			variable = line[7:]
 			if "," in variable:
@@ -235,7 +261,7 @@ class BasicParser(object):
 			self.UTILS["menu"]["enabled"] = True
 		else:
 			# Things that can be alone on a line
-			if line.startswith("getKey") or line.startswith("abs") or line.startswith("sqrt") or line.startswith("toString("):
+			if line.startswith("getKey") or line.startswith("abs") or line.startswith("sqrt") or line.startswith("toString(") or line.startswith('randInt('):
 				statement = line
 			else:
 				statement = "# UNKNOWN INDENTIFIER: {}".format(line)
@@ -271,6 +297,22 @@ class BasicParser(object):
 		if "toString(" in statement:
 			# Replace toString() with str() if toString() is not inside of quotes
 			statement = re.sub(r'toString\(([^\)]+)\)', r'str(\1)', statement)
+		if 'randInt(' in statement:
+			# Replace randInt with random.randint
+			statement = re.sub('randInt', 'random.randint', statement)
+
+			split_statement = parenthesis_split(closeOpen(statement))
+
+			for i in range(len((split_statement))):
+				if 'random.randint' in split_statement[i]:
+					args = re.search(r'random\.randint\((.*?)\)', split_statement[i]).group(1).replace(' ', '').split(',') # get data in between parentheses
+					if len(args) >= 3:
+						# Generate args[2] amount of random numbers
+						split_statement[i] = re.sub(r'random\.randint\(.*?\)', '[random.randint(' + args[0] + ', ' + args[1] + ') for i in range(' + args[2] + ')]', split_statement[i])
+
+			statement = ' '.join(split_statement)
+
+			self.UTILS['random']['enabled'] = True
 		return statement
 
 	def toPython(self):
